@@ -120,7 +120,7 @@ class FakePreseemModel:
                 for attr, val in kwargs.items():
                     if attr == 'company_uuid' or attr == 'uuid':
                         continue
-                    elif attr == 'active' and val is False:
+                    elif attr == 'inactive' and val is True:
                         FakePreseemModel._set_inactive(elem)
                     else:
                         setattr(elem, attr, val)
