@@ -86,10 +86,10 @@ async def sync_preseem_model(preseem_model, nm_model, company_uuid, system=None,
                 if elem_id not in bss_aps:
                     if verbose:
                         logging.info('Delete element: %s', elem)
-                    await preseem_model.Element.Update(uuid=elem.uuid, company_uuid=elem.company_uuid, active=False)
+                    await preseem_model.Element.Update(uuid=elem.uuid, company_uuid=elem.company_uuid, inactive=True)
 
             for site_id, site in model_sites.items():
                 if site_id not in bss_sites:
                     if verbose:
                         logging.info('Delete site: %s', site)
-                    await preseem_model.Site.Update(uuid=site.uuid, company_uuid=site.company_uuid, active=False)
+                    await preseem_model.Site.Update(uuid=site.uuid, company_uuid=site.company_uuid, inactive=True)
